# Wagtail 6.3 release notes - IN DEVELOPMENT

_Unreleased_

```{contents}
---
local:
depth: 1
---
```

## What's new

### Django 5.1 support

This release adds formal support for Django 5.1.

### Other features

 * Formalize support for MariaDB (Sage Abdullah, Daniel Black)
 * Redirect to the last viewed listing page after deleting form submissions (Matthias Brück)
 * Provide `getTextLabel` method on date / time StreamField blocks (Vaughn Dickson)
 * Purge frontend cache when modifying redirects (Jake Howard)
 * Migrate workflow history views to universal listings (Sage Abdullah)
 * Refactor documents views to use universal designs (Sage Abdullah)
 * Refactor images views to use universal designs (Sage Abdullah)
 * Implement universal listings for workflow usage and page type usage views (Sage Abdullah)
 * Add search and filters to form pages listing (Sage Abdullah)
 * Deprecate the `WAGTAIL_AUTO_UPDATE_PREVIEW` setting, use `WAGTAIL_AUTO_UPDATE_PREVIEW_INTERVAL = 0` instead (Sage Abdullah)
 * Consistently use `capfirst` for title-casing model verbose names (Sébastien Corbin)
 * Fire `copy_for_translation_done` signal when copying translatable models as well as pages (Coen van der Kamp)

### Bug fixes

 * Prevent page type business rules from blocking reordering of pages (Andy Babic, Sage Abdullah)
 * Improve layout of object permissions table (Sage Abdullah)
 * Fix typo in aria-label attribute of page explorer navigation link (Sébastien Corbin)
 * Reinstate transparency indicator on image chooser widgets (Sébastien Corbin)
 * Remove table headers that have no text (Matt Westcott)
 * Fix broken link to user search (Shlomo Markowitz)
 * Ensure that JS slugify function strips Unicode characters disallowed by Django slug validation (Atif Khan)
 * Do not show notices about root / unroutable pages when searching or filtering in the page explorer (Matt Westcott)
 * Resolve contrast issue for page deletion warning (Sanjeev Holla S)
 * Make sure content metrics falls back to body element only when intended (Sage Abdullah)
 * Remove wrongly-added filters from redirects index (Matt Westcott)
 * Prevent popular tags filter from generating overly complex queries when not filtering (Matt Westcott)
 * Fix content path links in usage view to scroll to the correct element (Sage Abdullah)
 * Always show the minimap toggle button (Albina Starykova)
 * Ensure invalid submissions are marked as dirty edits on load to trigger UI and browser warnings for unsaved changes, restoring previous behavior from Wagtail 5.2 (Sage Abdullah)
 * Update polldaddy oEmbed provider to use the crowdsignal URL (Matthew Scouten)
 * Remove polleverywhere oEmbed provider as it this application longer supports oEmbed (Matthew Scouten)
 * Ensure that dropdown button toggles show with a border in high contrast mode (Ishwari8104, LB (Ben) Johnston)

### Documentation

 * Upgrade Sphinx to 7.3 (Matt Westcott)
 * Document how to [customize date/time format settings](wagtail_date_time_formats) (Vince Salvino)
 * Create a new documentation section for [deployment](deployment_guide) and move `fly.io` deployment from the tutorial to this section (Vince Salvino)
 * Clarify process for [UserViewSet customization](custom_userviewset) (Sage Abdullah)
 * Correct `WAGTAIL_WORKFLOW_REQUIRE_REAPPROVAL_ON_EDIT` documentation to state that it defaults to `False` (Matt Westcott)
 * Add an example of customizing a default accessibility check (Cynthia Kiser)
 * Demonstrate access protection with `TokenAuthentication` in the [Wagtail API v2 Configuration Guide](/advanced_topics/api/v2/configuration) (Krzysztof Jeziorny)


### Maintenance

 * Removed support for Python 3.8 (Matt Westcott)
 * Drop `pytz` dependency in favour of `zoneinfo.available_timezones` (Sage Abdullah)
 * Relax `django-taggit` dependency to allow 6.0 (Matt Westcott)
 * Improve page listing performance (Sage Abdullah)
 * Phase out usage of `SECRET_KEY` in version and icon hashes (Jake Howard)
 * Audit all use of localized and non-localized numbers in templates (Matt Westcott)
 * Refactor StreamField `get_prep_value` for closer alignment with JSONField (Sage Abdullah)
 * Move search implementation logic from generic `IndexView` to `BaseListingView` (Sage Abdullah)
 * Upgrade Puppeteer integration tests for reliability (Matt Westcott)
 * Restore ability to use `.in_bulk()` on specific querysets under Django 5.2a0 (Sage Abdullah)
 * Add generated `test-media` to .gitignore (Shlomo Markowitz)
 * Improve `debounce` util's return type for better TypeScript usage (Sage Abdullah)
 * Ensure the side panel's show event is dispatched after any hide events (Sage Abdullah)
 * Migrate preview-panel JavaScript to Stimulus & TypeScript, add full unit testing (Sage Abdullah)
 * Move `wagtailConfig` values from inline scripts to the `wagtail_config` template tag (LB (Ben) Johnston, Sage Abdullah)
 * Deprecate the `{% locales %}` and `{% js_translation_strings %}` template tags (LB (Ben) Johnston, Sage Abdullah)
 * Adopt the modern best practice for `beforeunload` usage in `UnsavedController` to trigger a leave page warning when edits have been made (Shubham Mukati, Sage Abdullah)


## Upgrade considerations - changes affecting all projects

## Upgrade considerations - deprecation of old functionality

### Removed support for Python 3.8

Python 3.8 is no longer supported as of this release; please upgrade to Python 3.9 or above before upgrading Wagtail.

### Deprecation of the `WAGTAIL_AUTO_UPDATE_PREVIEW` setting

The [`WAGTAIL_AUTO_UPDATE_PREVIEW`](wagtail_auto_update_preview) setting has been deprecated and will be removed in a future release.

To disable the automatic preview update feature, set [`WAGTAIL_AUTO_UPDATE_PREVIEW_INTERVAL = 0`](wagtail_auto_update_preview_interval) in your Django settings instead.

## Upgrade considerations - changes affecting Wagtail customisations

## Upgrade considerations - changes to undocumented internals

### Deprecation of the `{% locales %}` template tag

The undocumented `locales` template tag will be removed in a future release.

If access to JSON locales within JavaScript is needed, use `window.wagtailConfig.LOCALES` instead.

### Deprecation of the `{% js_translation_strings %}` template tag

The undocumented `js_translation_strings` template tag will be removed in a future release.

If access to JSON translation strings within JavaScript is needed, use `window.wagtailConfig.STRINGS` instead.
